@@ -1,9 +1,8 @@
-;;; helm-pkg.el --- define helm for package.el
+;;; helm-core-pkg.el --- define helm-core for package.el
 
-(define-package "helm-core" "1.9.1"
+(define-package "helm-core" "1.9.2"
   "Development files for Helm"
-  '((emacs "24")
-    (cl-lib "0.5")
+  '((emacs "24.3")
     (async "1.6"))
   :url "https://emacs-helm.github.io/helm/")
 
