@@ -1,10 +1,10 @@
 ;;; helm-pkg.el --- define helm for package.el
 
-(define-package "helm" "1.9.1"
+(define-package "helm" "1.9.2"
   "Helm is an Emacs incremental and narrowing framework"
-  '((emacs "24")
-    (cl-lib "0.5")
+  '((emacs "24.3")
     (async "1.6")
+    (popup "0.5.3")
     (helm-core "1.9.1"))
   :url "https://emacs-helm.github.io/helm/")
 
