@@ -78,7 +78,10 @@
                                                helm-transform-file-cache))
   (set-slot-value source 'candidate-transformer '(helm-skip-boring-files
                                                   helm-highlight-files
-                                                  helm-w32-pathname-transformer)))
+                                                  helm-w32-pathname-transformer))
+  (set-slot-value source 'help-message 'helm-generic-file-help-message)
+  (set-slot-value source 'keymap helm-generic-files-map))
+
 
 ;; Bookmarks
 (defclass helm-type-bookmark (helm-source) ()
